@@ -21,6 +21,7 @@ has tx_status    => ( is => 'ro', isa => Enum [ $TX_STATUS_IDLE, $TX_STATUS_TRAN
 has wbuf         => ( is => 'ro', isa => ArrayRef,                                                     init_arg => undef );    # outgoing messages buffer
 has sth          => ( is => 'ro', isa => HashRef,                                                      init_arg => undef );    # currently executed sth
 has prepared_sth => ( is => 'ro', isa => HashRef,                                                      init_arg => undef );
+has query        => ( is => 'ro', isa => ScalarRef,                                                    init_arg => undef );    # ref to the last query
 
 const our $PROTOCOL_VER => "\x00\x03\x00\x00";                                                                                 # v3
 
@@ -220,7 +221,7 @@ sub _on_error ( $self, $reason, $fatal ) {
         $self->{state} = $STATE_DISCONNECTED;
     }
 
-    warn "DBI: $reason";
+    warn qq[DBI: "$reason"] . ( defined $self->{query} ? qq[, current query: "$self->{query}->$*"] : q[] );
 
     if ( $state == $STATE_BUSY ) {
         $self->{sth}->{error} = $reason;
@@ -574,6 +575,8 @@ sub _execute ( $self, $query, $bind, $cb, %args ) {
         utf8::encode $query if utf8::is_utf8 $query;
     }
 
+    $self->{query} = \$query;
+
     # simple query mode
     # multiple queries in single statement are allowed
     if ( !$use_extended_query ) {
@@ -978,20 +981,20 @@ sub quote ( $self, $var, $type = undef ) {
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ## | Sev. | Lines                | Policy                                                                                                         |
 ## |======+======================+================================================================================================================|
-## |    3 | 178                  | ControlStructures::ProhibitCascadingIfElse - Cascading if-elsif chain                                          |
+## |    3 | 179                  | ControlStructures::ProhibitCascadingIfElse - Cascading if-elsif chain                                          |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    3 | 523                  | Subroutines::ProhibitExcessComplexity - Subroutine "_execute" with high complexity score (27)                  |
+## |    3 | 524                  | Subroutines::ProhibitExcessComplexity - Subroutine "_execute" with high complexity score (27)                  |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    3 | 895                  | ControlStructures::ProhibitDeepNests - Code structure is deeply nested                                         |
+## |    3 | 898                  | ControlStructures::ProhibitDeepNests - Code structure is deeply nested                                         |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    2 | 25, 148, 356, 514,   | ValuesAndExpressions::ProhibitEscapedCharacters - Numeric escapes in interpolated string                       |
-## |      | 580, 590, 606, 611,  |                                                                                                                |
-## |      | 616, 622, 631, 638,  |                                                                                                                |
-## |      | 642, 646, 650, 653   |                                                                                                                |
+## |    2 | 26, 149, 357, 515,   | ValuesAndExpressions::ProhibitEscapedCharacters - Numeric escapes in interpolated string                       |
+## |      | 583, 593, 609, 614,  |                                                                                                                |
+## |      | 619, 625, 634, 641,  |                                                                                                                |
+## |      | 645, 649, 653, 656   |                                                                                                                |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    2 | 732, 895             | ControlStructures::ProhibitCStyleForLoops - C-style "for" loop used                                            |
+## |    2 | 735, 898             | ControlStructures::ProhibitCStyleForLoops - C-style "for" loop used                                            |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    2 | 771                  | ControlStructures::ProhibitPostfixControls - Postfix control "for" used                                        |
+## |    2 | 774                  | ControlStructures::ProhibitPostfixControls - Postfix control "for" used                                        |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
